# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-08 11:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix', '0010_corporateimage'),
    ]

